@@ -231,7 +231,21 @@ class ApiGatewayToSageMakerEndpoint(
         :summary: Constructs a new instance of the ApiGatewayToSageMakerEndpoint class.
         '''
         if __debug__:
-            type_hints = typing.get_type_hints(ApiGatewayToSageMakerEndpoint.__init__)
+            def stub(
+                scope: constructs.Construct,
+                id: builtins.str,
+                *,
+                endpoint_name: builtins.str,
+                request_mapping_template: builtins.str,
+                resource_path: builtins.str,
+                api_gateway_execution_role: typing.Optional[aws_cdk.aws_iam.Role] = None,
+                api_gateway_props: typing.Optional[typing.Union[aws_cdk.aws_apigateway.RestApiProps, typing.Dict[str, typing.Any]]] = None,
+                log_group_props: typing.Optional[typing.Union[aws_cdk.aws_logs.LogGroupProps, typing.Dict[str, typing.Any]]] = None,
+                resource_name: typing.Optional[builtins.str] = None,
+                response_mapping_template: typing.Optional[builtins.str] = None,
+            ) -> None:
+                ...
+            type_hints = typing.get_type_hints(stub)
             check_type(argname="argument scope", value=scope, expected_type=type_hints["scope"])
             check_type(argname="argument id", value=id, expected_type=type_hints["id"])
         props = ApiGatewayToSageMakerEndpointProps(
@@ -312,7 +326,19 @@ class ApiGatewayToSageMakerEndpointProps:
         if isinstance(log_group_props, dict):
             log_group_props = aws_cdk.aws_logs.LogGroupProps(**log_group_props)
         if __debug__:
-            type_hints = typing.get_type_hints(ApiGatewayToSageMakerEndpointProps.__init__)
+            def stub(
+                *,
+                endpoint_name: builtins.str,
+                request_mapping_template: builtins.str,
+                resource_path: builtins.str,
+                api_gateway_execution_role: typing.Optional[aws_cdk.aws_iam.Role] = None,
+                api_gateway_props: typing.Optional[typing.Union[aws_cdk.aws_apigateway.RestApiProps, typing.Dict[str, typing.Any]]] = None,
+                log_group_props: typing.Optional[typing.Union[aws_cdk.aws_logs.LogGroupProps, typing.Dict[str, typing.Any]]] = None,
+                resource_name: typing.Optional[builtins.str] = None,
+                response_mapping_template: typing.Optional[builtins.str] = None,
+            ) -> None:
+                ...
+            type_hints = typing.get_type_hints(stub)
             check_type(argname="argument endpoint_name", value=endpoint_name, expected_type=type_hints["endpoint_name"])
             check_type(argname="argument request_mapping_template", value=request_mapping_template, expected_type=type_hints["request_mapping_template"])
             check_type(argname="argument resource_path", value=resource_path, expected_type=type_hints["resource_path"])
